==> haskell-persistent-sqlite-2.13.1.0-137-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-sqlite
version:              2.13.1.0
visibility:           public
id:                   persistent-sqlite-2.13.1.0-HcavhQ3FLCCEFTK6j509o0
key:                  persistent-sqlite-2.13.1.0-HcavhQ3FLCCEFTK6j509o0
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:             Database, Yesod
abi:                  8dd3b69a5c2c132a78525fd06375e4ad
exposed:              True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-sqlite-2.13.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-sqlite-2.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-sqlite
hs-libraries:         HSpersistent-sqlite-2.13.1.0-HcavhQ3FLCCEFTK6j509o0
extra-libraries:      pthread sqlite3
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh
    containers-0.6.5.1 microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    monad-logger-0.3.40-IGuplPtapPo80SzOUYqwUL mtl-2.2.2
    persistent-2.14.5.1-Lra5mco7v3oDrLn8V2e89
    resource-pool-0.2.3.2-LMVWhOxYjv3756PAY3BjzE
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.0-156.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-sqlite
version:              2.13.1.0
visibility:           public
id:                   persistent-sqlite-2.13.1.0-2W9W2K2jnKQGXqs7Op5z2F
key:                  persistent-sqlite-2.13.1.0-2W9W2K2jnKQGXqs7Op5z2F
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:             Database, Yesod
abi:                  30d05a2116f3628c89ba532bcd17570b
exposed:              True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-sqlite-2.13.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-sqlite-2.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-sqlite
hs-libraries:         HSpersistent-sqlite-2.13.1.0-2W9W2K2jnKQGXqs7Op5z2F
extra-libraries:      pthread sqlite3
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    containers-0.6.5.1 microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa mtl-2.2.2
    persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
    resource-pool-0.2.3.2-2ghaoAEpV2r22WQ70y4rca
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
